
package com.madhu.xml;

import java.io.*;
import org.xml.sax.*;
import org.xml.sax.helpers.*;

public class SAXValidator extends DefaultHandler {
	private boolean valid;
	private boolean wellFormed;

	public SAXValidator() {
		valid = true;
		wellFormed = true;
	}

	public void startDocument() {
		System.out.println("***Start of Document***");
	}

	public void endDocument() {
		System.out.println("***End of Document***");
	}

	public void error(SAXParseException e) {
		valid = false;
	}

	public void fatalError(SAXParseException e) {
		wellFormed = false;
	}

	public void warning(SAXParseException e) {
		valid = false;
	}

	public boolean isValid() {
		return valid;
	}

	public boolean isWellFormed() {
		return wellFormed;
	}

	public static void main(String args[]) throws Exception {
		if (args.length != 1) {
			System.err.println("Usage: java SAXValidate <xml-file>");
			System.exit(1);
		}

		XMLReader parser = XMLReaderFactory.createXMLReader(
			"org.apache.xerces.parsers.SAXParser");

		parser.setFeature("http://xml.org/sax/features/validation", true);

		SAXValidator handler = new SAXValidator();
		parser.setContentHandler(handler);
		parser.setErrorHandler(handler);

		parser.parse(new InputSource(new FileReader(args[0])));
		if (!handler.isWellFormed()) {
			System.out.println("Document is NOT well formed.");
		}
		if (!handler.isValid()) {
			System.out.println("Document is NOT valid.");
		}
		if (handler.isWellFormed() && handler.isValid()) {
			System.out.println("Document is well formed and valid.");
		}
	}
}
