
package com.madhu.spider;

import java.io.*;
import java.util.*;
import java.net.*;

import org.xml.sax.*;
import hplb.xml.Tokenizer;

public class Spider {
	private int numberOfStates;
	private PrintWriter out;

	public void process(String nStates, String outFile)
		throws Exception {

		numberOfStates = Integer.parseInt(nStates);
		out = new PrintWriter(new FileWriter(outFile));
		processUSA();
		out.close();
	}

	// Base URL: http://quickfacts.census.gov/qfd/index.html

	public void processUSA() throws Exception {
		USAHandler usa = new USAHandler();
		Tokenizer t = new Tokenizer();
		t.setDocumentHandler(usa);
		t.setErrorHandler(usa);
		URL u = new URL("http://quickfacts.census.gov/qfd/index.html");
		InputStream is = u.openStream();
		t.parse(is);
		is.close();

		int nStates = numberOfStates;
		Iterator it = usa.getStateNames();
		while (it.hasNext() && nStates-- > 0) {
			String state = (String) it.next();
			String url = "http://quickfacts.census.gov" + usa.getStateURI(state);
			processState(state, url);
		}
	}

	public void processState(String state, String url)
		throws Exception {

		StateHandler st = new StateHandler();
		Tokenizer t = new Tokenizer();
		t.setDocumentHandler(st);
		t.setErrorHandler(st);
		URL u = new URL(url);
		InputStream is = u.openStream();
		t.parse(is);
		is.close();

		System.out.println(state);
		out.print("\"" + state + "\"");
		ArrayList dataList = st.getDataList();
		int n = dataList.size();
		for (int i=0; i<n; i+=1) {
			String[] data = (String[]) dataList.get(i);
			out.print(", \"" + data[1] + "\"");
		}
		out.println();
	}

	public static void main(String args[]) throws Exception {
		if (args.length != 2) {
			System.err.println("Usage: java Spider <# of states> <out-file>");
			System.exit(1);
		}
		Spider m = new Spider();
		m.process(args[0], args[1]);
	}
}
